@@ -16,8 +16,8 @@
 # under the License.
 
 #' @importFrom R6 R6Class
-#' @importFrom purrr map map_int map_lgl map_chr map2
-#' @importFrom assertthat assert_that
+#' @importFrom purrr as_mapper map map2 map_chr map_dfr map_int map_lgl
+#' @importFrom assertthat assert_that is.string
 #' @importFrom rlang list2 %||% is_false abort dots_n warn enquo quo_is_null enquos is_integerish quos eval_tidy new_data_mask syms env env_bind as_label set_names
 #' @importFrom Rcpp sourceCpp
 #' @importFrom tidyselect vars_select
@@ -39,6 +39,12 @@
       s3_register(m, cl)
     }
   }
+
+  s3_register("dplyr::tbl_vars", "arrow_dplyr_query")
+  s3_register("reticulate::py_to_r", "pyarrow.lib.Array")
+  s3_register("reticulate::py_to_r", "pyarrow.lib.RecordBatch")
+  s3_register("reticulate::r_to_py", "Array")
+  s3_register("reticulate::r_to_py", "RecordBatch")
   invisible()
 }
 
@@ -61,7 +67,7 @@ option_use_threads <- function() {
 }
 
 #' @include enums.R
-Object <- R6Class("Object",
+ArrowObject <- R6Class("ArrowObject",
   public = list(
     initialize = function(xp) self$set_pointer(xp),
 
@@ -75,10 +81,16 @@ Object <- R6Class("Object",
           call. = FALSE
         )
       }
-      self$`.:xp:.` <- xp
+      assign(".:xp:.", xp, envir = self)
     },
-    print = function(...){
-      cat(class(self)[[1]], "\n", sep = "")
+    print = function(...) {
+      if (!is.null(self$.class_title)) {
+        # Allow subclasses to override just printing the class name first
+        class_title <- self$.class_title()
+      } else {
+        class_title <- class(self)[[1]]
+      }
+      cat(class_title, "\n", sep = "")
       if (!is.null(self$ToString)){
         cat(self$ToString(), "\n", sep = "")
       }
@@ -88,16 +100,16 @@ Object <- R6Class("Object",
 )
 
 #' @export
-`!=.Object` <- function(lhs, rhs) !(lhs == rhs)
+`!=.ArrowObject` <- function(lhs, rhs) !(lhs == rhs)
 
 #' @export
-`==.Object` <- function(x, y) {
+`==.ArrowObject` <- function(x, y) {
   x$Equals(y)
 }
 
 #' @export
-all.equal.Object <- function(target, current, ...) {
-  target$Equals(current)
+all.equal.ArrowObject <- function(target, current, ..., check.attributes = TRUE) {
+  target$Equals(current, check_metadata = check.attributes)
 }
 
 shared_ptr <- function(class, xp) {
