@@ -21,7 +21,7 @@
 
 # OutputStream ------------------------------------------------------------
 
-Writable <- R6Class("Writable", inherit = Object,
+Writable <- R6Class("Writable", inherit = ArrowObject,
   public = list(
     write = function(x) io___Writable__write(self, buffer(x))
   )
@@ -29,10 +29,8 @@ Writable <- R6Class("Writable", inherit = Object,
 
 #' @title OutputStream classes
 #' @description `FileOutputStream` is for writing to a file;
-#' `BufferOutputStream` and `FixedSizeBufferWriter` write to buffers;
-#' `MockOutputStream` just reports back how many bytes it received, for testing
-#' purposes. You can create one and pass it to any of the table writers, for
-#' example.
+#' `BufferOutputStream` writes to a buffer;
+#' You can create one and pass it to any of the table writers, for example.
 #' @usage NULL
 #' @format NULL
 #' @docType class
@@ -44,10 +42,6 @@ Writable <- R6Class("Writable", inherit = Object,
 #' - `path` For `FileOutputStream`, a character file name
 #' - `initial_capacity` For `BufferOutputStream`, the size in bytes of the
 #'    buffer.
-#' - `x` For `FixedSizeBufferWriter`, a [Buffer] or an object that can be
-#'    made into a buffer via `buffer()`.
-#'
-#' `MockOutputStream$create()` does not take any arguments.
 #'
 #' @section Methods:
 #'
@@ -55,7 +49,7 @@ Writable <- R6Class("Writable", inherit = Object,
 #'  - `$close()`: close the stream
 #'  - `$write(x)`: send `x` to the stream
 #'  - `$capacity()`: for `BufferOutputStream`
-#'  - `$getvalue()`: for `BufferOutputStream`
+#'  - `$finish()`: for `BufferOutputStream`
 #'  - `$GetExtentBytesWritten()`: for `MockOutputStream`, report how many bytes
 #'    were sent.
 #'
@@ -77,19 +71,6 @@ FileOutputStream$create <- function(path) {
   shared_ptr(FileOutputStream, io___FileOutputStream__Open(clean_path_abs(path)))
 }
 
-#' @usage NULL
-#' @format NULL
-#' @rdname OutputStream
-#' @export
-MockOutputStream <- R6Class("MockOutputStream", inherit = OutputStream,
-  public = list(
-    GetExtentBytesWritten = function() io___MockOutputStream__GetExtentBytesWritten(self)
-  )
-)
-MockOutputStream$create <- function() {
-  shared_ptr(MockOutputStream, io___MockOutputStream__initialize())
-}
-
 #' @usage NULL
 #' @format NULL
 #' @rdname OutputStream
@@ -97,7 +78,7 @@ MockOutputStream$create <- function() {
 BufferOutputStream <- R6Class("BufferOutputStream", inherit = OutputStream,
   public = list(
     capacity = function() io___BufferOutputStream__capacity(self),
-    getvalue = function() shared_ptr(Buffer, io___BufferOutputStream__Finish(self)),
+    finish = function() shared_ptr(Buffer, io___BufferOutputStream__Finish(self)),
     write = function(bytes) io___BufferOutputStream__Write(self, bytes),
     tell = function() io___BufferOutputStream__Tell(self)
   )
@@ -106,21 +87,10 @@ BufferOutputStream$create <- function(initial_capacity = 0L) {
   shared_ptr(BufferOutputStream, io___BufferOutputStream__Create(initial_capacity))
 }
 
-#' @usage NULL
-#' @format NULL
-#' @rdname OutputStream
-#' @export
-FixedSizeBufferWriter <- R6Class("FixedSizeBufferWriter", inherit = OutputStream)
-FixedSizeBufferWriter$create <- function(x) {
-  x <- buffer(x)
-  assert_that(x$is_mutable)
-  shared_ptr(FixedSizeBufferWriter, io___FixedSizeBufferWriter__initialize(x))
-}
-
 # InputStream -------------------------------------------------------------
 
 
-Readable <- R6Class("Readable", inherit = Object,
+Readable <- R6Class("Readable", inherit = ArrowObject,
   public = list(
     Read = function(nbytes) shared_ptr(Buffer, io___Readable__Read(self, nbytes))
   )
@@ -248,13 +218,12 @@ mmap_open <- function(path, mode = c("read", "write", "readwrite")) {
 }
 
 #' Handle a range of possible input sources
-#' @param file A character file name, raw vector, or an Arrow input stream
+#' @param file A character file name, `raw` vector, or an Arrow input stream
 #' @param mmap Logical: whether to memory-map the file (default `TRUE`)
 #' @return An `InputStream` or a subclass of one.
 #' @keywords internal
 make_readable_file <- function(file, mmap = TRUE) {
-  if (is.character(file)) {
-    assert_that(length(file) == 1L)
+  if (is.string(file)) {
     if (isTRUE(mmap)) {
       file <- mmap_open(file)
     } else {
