@@ -40,6 +40,7 @@ int ChunkedArray__num_chunks(const std::shared_ptr<arrow::ChunkedArray>& chunked
 // [[arrow::export]]
 std::shared_ptr<arrow::Array> ChunkedArray__chunk(
     const std::shared_ptr<arrow::ChunkedArray>& chunked_array, int i) {
+  arrow::r::validate_index(i, chunked_array->num_chunks());
   return chunked_array->chunk(i);
 }
 
@@ -57,12 +58,15 @@ std::shared_ptr<arrow::DataType> ChunkedArray__type(
 // [[arrow::export]]
 std::shared_ptr<arrow::ChunkedArray> ChunkedArray__Slice1(
     const std::shared_ptr<arrow::ChunkedArray>& chunked_array, int offset) {
+  arrow::r::validate_slice_offset(offset, chunked_array->length());
   return chunked_array->Slice(offset);
 }
 
 // [[arrow::export]]
 std::shared_ptr<arrow::ChunkedArray> ChunkedArray__Slice2(
     const std::shared_ptr<arrow::ChunkedArray>& chunked_array, int offset, int length) {
+  arrow::r::validate_slice_offset(offset, chunked_array->length());
+  arrow::r::validate_slice_length(length, chunked_array->length() - offset);
   return chunked_array->Slice(offset, length);
 }
 
@@ -70,9 +74,7 @@ std::shared_ptr<arrow::ChunkedArray> ChunkedArray__Slice2(
 std::shared_ptr<arrow::ChunkedArray> ChunkedArray__View(
     const std::shared_ptr<arrow::ChunkedArray>& array,
     const std::shared_ptr<arrow::DataType>& type) {
-  std::shared_ptr<arrow::ChunkedArray> out;
-  STOP_IF_NOT_OK(array->View(type, &out));
-  return out;
+  return VALUE_OR_STOP(array->View(type));
 }
 
 // [[arrow::export]]
