@@ -73,12 +73,19 @@ std::string Schema__metadata(const std::shared_ptr<arrow::Schema>& schema) {
   return schema->metadata()->ToString();
 }
 
+// [[arrow::export]]
+std::shared_ptr<arrow::Schema> Schema__WithMetadata(
+    const std::shared_ptr<arrow::Schema>& schema, Rcpp::CharacterVector metadata) {
+  auto kv = std::shared_ptr<arrow::KeyValueMetadata>(new arrow::KeyValueMetadata(
+      metadata.names(), Rcpp::as<std::vector<std::string>>(metadata)));
+  return schema->WithMetadata(kv);
+}
+
 // [[arrow::export]]
 Rcpp::RawVector Schema__serialize(const std::shared_ptr<arrow::Schema>& schema) {
   arrow::ipc::DictionaryMemo empty_memo;
-  std::shared_ptr<arrow::Buffer> out;
-  STOP_IF_NOT_OK(arrow::ipc::SerializeSchema(*schema, &empty_memo,
-                                             arrow::default_memory_pool(), &out));
+  std::shared_ptr<arrow::Buffer> out =
+      VALUE_OR_STOP(arrow::ipc::SerializeSchema(*schema, &empty_memo));
 
   auto n = out->size();
   Rcpp::RawVector vec(out->size());
@@ -93,4 +100,10 @@ bool Schema__Equals(const std::shared_ptr<arrow::Schema>& schema,
   return schema->Equals(*other, check_metadata);
 }
 
+// [[arrow::export]]
+std::shared_ptr<arrow::Schema> arrow__UnifySchemas(
+    const std::vector<std::shared_ptr<arrow::Schema>>& schemas) {
+  return VALUE_OR_STOP(arrow::UnifySchemas(schemas));
+}
+
 #endif
